.. _building_a_pipeline_ref:
.. currentmodule:: skrub

Building a pipeline
===================

.. autosummary::
   :toctree: generated/
   :template: function.rst
   :nosignatures:

   tabular_learner

.. autosummary::
   :toctree: generated/
   :template: class.rst
   :nosignatures:

   TableVectorizer
   SelectCols
   DropCols
